pub struct InitializeWithData {
pub payer: Pubkey,
pub authority: Pubkey,
pub descriptor: Pubkey,
pub mint: Pubkey,
pub token_metadata: Pubkey,
pub token_metadata_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializeWithData.
Fields
payer: Pubkeyentity that funds transaction
descriptor authority, same as metadata update authority
descriptor: Pubkeymint: Pubkeymint associated with the descriptor
token_metadata: Pubkeytoken_metadata_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeWithDatawhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeWithDatawhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializeWithData
impl ToAccountMetas for InitializeWithData
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeWithData
impl RefUnwindSafe for InitializeWithData
impl Send for InitializeWithData
impl Sync for InitializeWithData
impl Unpin for InitializeWithData
impl UnwindSafe for InitializeWithData